#
# spec file for package ghc-network-control
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name network-control
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.7
Release:        1.1
Summary:        Library to control network protocols
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-psqueues-devel
BuildRequires:  ghc-psqueues-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unix-time-devel
BuildRequires:  ghc-unix-time-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-pretty-simple-devel
BuildRequires:  ghc-pretty-simple-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
%endif

%description
Common parts to control network protocols.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc Changelog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sun May 18 2025 Peter Simons <psimons@suse.com>
- Update network-control to version 0.1.7.
  [#]# 0.1.7
  * Implementing setLRUCapacity.
* Sun Mar 30 2025 Peter Simons <psimons@suse.com>
- Update network-control to version 0.1.6.
  [#]# 0.1.6
  * Allowing size 0.
* Fri Mar 28 2025 Peter Simons <psimons@suse.com>
- Update network-control to version 0.1.5.
  [#]# 0.1.5
  * New API: `lookup'` adjusts the target priority.
  * New API: `LRUCacheRef` stuffs
  * `insert` rebuilds PSQ when reached the limit.
* Tue Jan 28 2025 Peter Simons <psimons@suse.com>
- Update network-control to version 0.1.4.
  [#]# 0.1.4
  * Using Integer instead of Int in LRUCache.
* Thu Jul 18 2024 Peter Simons <psimons@suse.com>
- Update network-control to version 0.1.3.
  [#]# 0.1.3
  * Simplify `maybeOpenRxWindow` and improve docs
    [#7](https://github.com/kazu-yamamoto/network-control/pull/7)
  [#]# 0.1.2
  * introducing a minimum size for window update
    [#5](https://github.com/kazu-yamamoto/network-control/pull/5)
  [#]# 0.1.1
  * Change defaultMaxData
    [#4](https://github.com/kazu-yamamoto/network-control/pull/4)
  [#]# 0.1.0
  * Breaking change: Renaming rxfWindow to rxfBufSize.
  * Updating the document about flow control.
* Thu Nov 23 2023 Peter Simons <psimons@suse.com>
- Add network-control at version 0.0.2.
